@@ -152,23 +152,30 @@ createIntamapObject = function(observations, obsChar, formulaString, predictionL
   class(object) = class
   if ("methodParameters" %in% names(params)) {
     methodParameters = params$methodParameters
-    if (length(grep("system",methodParameters)) >0) stop("Illegal attempt to call system functions through methodParameters")
-    if (length(grep("scan",methodParameters)) >0) stop("Illegal attempt to call function scan through methodParameters")
-    if (length(grep("read",methodParameters)) >0) stop("Illegal attempt to call function read* through methodParameters")
-    if (length(grep("count",methodParameters)) >0) stop("Illegal attempt to call function count* through methodParameters")
-    if (length(grep("write",methodParameters)) >0) stop("Illegal attempt to call function write through methodParameters")
-    if (length(grep("sink",methodParameters)) >0) stop("Illegal attempt to call function sink through methodParameters")
-    if (length(grep("call",methodParameters)) >0) stop("Illegal attempt to call function call through methodParameters")
-    if (length(grep("eval",methodParameters)) >0) stop("Illegal attempt to call function eval through methodParameters")
     if (length(grep("assign",methodParameters)) >0) stop("Illegal attempt to call function assign through methodParameters")
-    if (length(grep(" rm",methodParameters)) >0) stop("Illegal attempt to call function rm through methodParameters")
-    if (length(grep("download",methodParameters)) >0) stop("Illegal attempt to download through methodParameters")
-    if (length(grep("url",methodParameters)) >0) stop("methodParameters contain illegal string url")
+    if (length(grep("call",methodParameters)) >0) stop("Illegal attempt to call function call through methodParameters")
+    if (length(grep("cat",methodParameters)) >0) stop("Illegal attempt to call function cat through methodParameters")
+    if (length(grep("count",methodParameters)) >0) stop("Illegal attempt to call function count* through methodParameters")
+    if (length(grep("download",methodParameters)) >0) stop("Illegal attempt to call function download through methodParameters")
     if (length(grep("env",methodParameters)) >0) stop("methodParameters contain illegal string env")
-    if (length(grep("options",methodParameters)) >0) stop("methodParameters contain illegal string options")
-    if (length(grep("file",methodParameters)) >0) stop("methodParameters contain illegal string file")
+    if (length(grep("eval",methodParameters)) >0) stop("Illegal attempt to call function eval through methodParameters")
+    if (length(grep("file",methodParameters)) >0) stop("Illegal attempt to call function file* through methodParameters")
+    if (length(grep("format",methodParameters)) >0) stop("Illegal attempt to call function format* through methodParameters")
+    if (length(grep("gettext",methodParameters)) >0) stop("Illegal attempt to call function gettext through methodParameters")
+    if (length(grep("options",methodParameters)) >0) stop("Illegal attempt to call function options through methodParameters")
+    if (length(grep("parse",methodParameters)) >0) stop("Illegal attempt to call function parse through methodParameters")
+    if (length(grep("paste",methodParameters)) >0) stop("Illegal attempt to call function paste through methodParameters")
+    if (length(grep("print",methodParameters)) >0) stop("Illegal attempt to call function print through methodParameters")
     if (length(grep(" q",methodParameters)) >0) stop("methodParameters contain illegal string q")
-    if (length(grep("shell",methodParameters)) >0) stop("methodParameters contain illegal string shell")
+    if (length(grep("read",methodParameters)) >0) stop("Illegal attempt to call function read* through methodParameters")
+    if (length(grep(" rm",methodParameters)) >0) stop("Illegal attempt to call function rm through methodParameters")
+    if (length(grep("scan",methodParameters)) >0) stop("Illegal attempt to call function scan through methodParameters")
+    if (length(grep("sink",methodParameters)) >0) stop("Illegal attempt to call function sink through methodParameters")
+    if (length(grep("shell",methodParameters)) >0) stop("Illegal attempt to call function shell through methodParameters")
+    if (length(grep("sprintf",methodParameters)) >0) stop("Illegal attempt to call function sprintf through methodParameters")
+    if (length(grep("system",methodParameters)) >0) stop("Illegal attempt to call function system through methodParameters")
+    if (length(grep("url",methodParameters)) >0) stop("methodParameters contain illegal string url")
+    if (length(grep("write",methodParameters)) >0) stop("Illegal attempt to call function write through methodParameters")
    
     params = params[-which(names(params) == "methodParameters")]
     eval(parse(text = methodParameters))
